Destruct

Derive Macro Destruct 

#[derive(Destruct)]
{
    // Attributes available to this derive:
    #[nullable]
    #[no_drop]
}
The Destruct derive macro.

Generate a destructor for the structure.

Field Attributes

  • #[nullable] - The field is nullable, the destructor will check if the pointer is null before
  • #[no_drop] - The field will not be added to the destructor